@@ -152,7 +152,7 @@ public:
 
     typedef std::vector<std::pair<size_t, size_t>> RangeVector;
 
-    bool		 addToFileName(const T* s); //modifies a filename, adds the provided string to file name but keeps extension and path
+	bool		 addToFileName(const T* s); //modifies a filename, adds the provided string to file name but keeps extension and path
     bool         alloc(size_t len);
     CTextT&      append(const CTextT& s);
     CTextT&      append(const T* s); // append string
@@ -181,7 +181,7 @@ public:
     bool         containAny(const T* cList, bool bCase = true) const; // returns true if our string contains any of the characters of the list
     bool         containOnly(const T* cList, bool bCase = true) const; // returns true if our string contains only characters from the list   
     bool         contain(const T c, size_t from, size_t to) const; // search in range
-    void	     copyTo(T* s);  //copy the string data to the external buffer (should be large enough)
+	void	     copyTo(T* s);  //copy the string data to the external buffer (should be large enough)
     void	     copyTo(T* s, size_t max_len); //copy the string data to the external buffer (should be large enough)
     size_t       count(T c, size_t from = 0) const;  //returns the count of occurences of the given character
     size_t       count(const T* s, bool bCase = false) const;  //returns the count of occurences of the given substring
@@ -220,7 +220,7 @@ public:
     bool         endsWithAny(const T* cList, bool bCase = true) const;
     ContS bool   endsWithAny(const C& list, size_t from = 0, bool bCase = true, bool useTrie = false, size_t* idx = nullptr) const;  //returns true if end with any of the provided strings
     size_t       erase(size_t from, size_t count = 1);  // delete count characters starting at zero-based index
-    const T*     find(const T c, bool bCase = true) const;// return a pointer to the first occurence of the character, or 0 pointer if not found
+	const T*     find(const T c, bool bCase = true) const;// return a pointer to the first occurence of the character, or 0 pointer if not found
     const T*     find(const T *s, bool bCase = true) const; // return a pointer to the first occurence of the string, or 0 pointer if not found
     size_t       findBlockPositions(const T* sepBegin, const T* sepEnd, std::vector< std::pair<size_t, size_t>>& pos, bool bCase = true) const; //find begin/end positions of all blocks beggining and ending with the given separators
     size_t       findPositions(RangeVector& pos, size_t skip, bool appendSeparators = false, const T* sep = SeparatorsLine) const;
@@ -236,8 +236,8 @@ public:
     bool         fromHex(const T* s); // reverse of toHex, text "48 65 6C 6C 6F 20 57 6F 72 6C 64" --> "HelloWorld" 
     DefN bool    fromHexNumber(Num i, bool hasBase = true, bool upper = false, bool append = false); // create a hexadecimal string from the number
     bool         fromDouble(double d, int precision = 6, bool fixed = true, bool nozeros = false, bool append = false);
-    bool         fromSingle(const char* s);  // init with single-char ANSI string, make string -> wstring convert if necessary
-    bool         fromWide(const wchar_t* s);  // init with UNICODE string, make wstring -> string convert if necessary
+    void         fromSingle(const char* s);  // init with single-char ANSI string, make string -> wstring convert if necessary
+    void         fromWide(const wchar_t* s);  // init with UNICODE string, make wstring -> string convert if necessary
     bool         fromTChars(const char * s);
     bool         fromTChars(const wchar_t * s);
  ContS CTextT&   fromArray(const C& container, const T* sep = SPACE); // compose back the string using the given separator, if asHex is set will convert values in the array to hex strings
@@ -466,8 +466,8 @@ inline const T*  str(size_t from = 0) const; //return pointer to modifiable buff
 
     // static functions overloads 
     static size_t            CopyAsTchar(const char* str, T* tstr, size_t max_len);
-    inline static bool       FromSingle(const char* s, CTextT& res);
-    inline static bool       FromWide(const wchar_t* s, CTextT& res);
+    inline static CTextT     FromSingle(const char* s);
+    inline static CTextT     FromWide(const wchar_t* s);
   DefT inline static bool    ReadFile(const CharT* filePath, CTextT& s);
     inline static bool       ReadLinesFromFile(const T* path, CTextT& res, size_t lineStart, size_t lineEnd);
 inline static CTextT<char>   ToSingle(const T* s);
