@@ -272,8 +272,8 @@ PYBIND11_MODULE(ctextlib, m)
         .def("fromMatrix", [](CTextU& s, py::array_t<double> m, const wchar_t* sep, const wchar_t* sepLine)->void {   py::buffer_info buf = m.request();  size_t h = buf.shape[0]; size_t w = buf.shape[1]; double* ptr = (double*)buf.ptr; s.fromMatrix<double>(ptr, w, h, false, 2, sep, sepLine);  }, "//compose string from a 2D numerical matrix", py::arg("list"), py::arg("sep") = CTextU::SPACE, py::arg("sepLine") = CTextU::EOL)
         .def("fromMatrixAsHex", [](CTextU& s, py::array_t<int> m, int wHex, const wchar_t* sep, const wchar_t* sepLine)->void {   py::buffer_info buf = m.request();  size_t h = buf.shape[0]; size_t w = buf.shape[1]; int* ptr = (int*)buf.ptr; s.fromMatrix<int>(ptr, w, h, true, wHex, sep, sepLine);  }, "//compose string from a 2D numerical matrix", py::arg("list"), py::arg("wHex") = 2, py::arg("sep") = CTextU::SPACE, py::arg("sepLine") = CTextU::EOL)
         .def("getDir", &CTextU::getDir, "get a folder from a full module path")
-        .def("getExtension", &CTextU::getExtension, "if our string contains file path, return pointer to the extension")
-        .def("getFileName", &CTextU::getFileName, "if our string contains file path, return pointer to the file name")
+        .def("getExtension", &CTextU::getExtension, "if our string contains file path, return the extension")
+        .def("getFileName", &CTextU::getFileName, "if our string contains file path, return the file name")
         .def("hash", &CTextU::hash)
         .def("indexOf", [](CTextU& s, const wchar_t* str, size_t from, bool bCase)->size_t { return s.lastIndexOf(str, from, bCase); }, "find the offset of first instance of the string in the list, return index or -1 if not found", py::arg("str"), py::arg("from") = 0, py::arg("case") = true)
         .def("indexOfAny", [](CTextU& s, const wchar_t* cList, bool bCase)->size_t { return s.indexOfAny(cList, 0, bCase); }, "find the offset of the first instance of the characters in the list", py::arg("cList"), py::arg("case") = true)
